@@ -951,8 +951,11 @@ def setup():
 
 
 def main():
-    def b_key_pressed(world):
+    def b_key_pressed(world:World):
         print("b pressed. player at", world.player_position())
+        x,y,z = world.player_postion()
+        world.setBlock(x,y,z, "default:brick")
+        
     world = World("DEMO")
     print("Block types", World.MATERIALS.keys())
     world.build_key_function = b_key_pressed
